@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bsplash.cpp,v 1.16.2.1 2004/06/18 12:44:32 trueg Exp $
+ * $Id: k3bsplash.cpp 391594 2005-02-21 01:43:45Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -16,6 +16,7 @@
 #include "k3bsplash.h"
 
 #include <k3bthememanager.h>
+#include <k3bapplication.h>
 
 #include <qapplication.h>
 #include <qlabel.h>
@@ -31,23 +32,29 @@
 
 
 K3bSplash::K3bSplash( QWidget* parent, const char* name )
-  : QVBox( parent, name, WType_Dialog|WStyle_Customize|WStyle_NoBorder|WDestructiveClose|WStyle_StaysOnTop )
+  : QVBox( parent, name, 
+	   WStyle_Customize|
+	   WDestructiveClose|
+	   /*WStyle_Splash*/WType_Dialog|
+	   /*	   WShowModal|*/
+	   WStyle_NoBorder|
+	   WStyle_StaysOnTop )
 {
   setMargin( 0 );
   setSpacing( 0 );
 
   QLabel* copyrightLabel = new QLabel( kapp->aboutData()->copyrightStatement(), this );
-  copyrightLabel->setMargin( 2 );
+  copyrightLabel->setMargin( 5 );
   copyrightLabel->setPaletteBackgroundColor( black );
   copyrightLabel->setPaletteForegroundColor( white );
   copyrightLabel->setAlignment( AlignRight );
 
   QLabel* picLabel = new QLabel( this );
-  if( K3bTheme* theme = k3bthememanager->currentTheme() )
-    picLabel->setPixmap( theme->pixmap( "k3b_splash" ) );
+  if( K3bTheme* theme = k3bappcore->themeManager()->currentTheme() )
+    picLabel->setPixmap( theme->pixmap( K3bTheme::SPLASH ) );
 
   m_infoBox = new QLabel( this );
-  m_infoBox->setMargin( 2 );
+  m_infoBox->setMargin( 5 );
   m_infoBox->setPaletteBackgroundColor( black );
   m_infoBox->setPaletteForegroundColor( white );
 
