@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bstatusbarmanager.h,v 1.4 2004/01/26 17:21:00 trueg Exp $
+ * $Id: k3bstatusbarmanager.h 317459 2004-06-03 20:20:22Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -41,6 +41,8 @@ class K3bStatusBarManager : public QObject
 
  private slots:
   void slotFreeTempSpace( const QString&, unsigned long, unsigned long, unsigned long );
+  void showActionStatusText( const QString& text );
+  void clearActionStatusText();
 
  private:
   bool eventFilter( QObject* o, QEvent* e );
@@ -48,6 +50,7 @@ class K3bStatusBarManager : public QObject
   QLabel* m_labelInfoMessage;
   QLabel* m_pixFreeTemp;
   QLabel* m_labelFreeTemp;
+  QLabel* m_versionBox;
   K3bBusyWidget* m_busyWidget;
 
   K3bMainWindow* m_mainWindow;
