@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bsystemproblemdialog.cpp,v 1.23.2.4 2005/01/19 12:54:41 trueg Exp $
+ * $Id: k3bsystemproblemdialog.cpp 397363 2005-03-13 20:27:13Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -17,12 +17,11 @@
 #include <config.h>
 
 
-#include "k3bcore.h"
+#include "k3bapplication.h"
 #include "k3bsystemproblemdialog.h"
-#include "tools/k3btitlelabel.h"
+#include <k3btitlelabel.h>
 #include <k3bexternalbinmanager.h>
 #include <k3bstdguiitems.h>
-#include <k3bexternalbinmanager.h>
 #include <k3bdevicemanager.h>
 #include <k3bdevice.h>
 #include <k3bversion.h>
@@ -34,6 +33,7 @@
 #include <qcheckbox.h>
 #include <qlayout.h>
 #include <qlabel.h>
+#include <qfileinfo.h>
 
 #include <klocale.h>
 #include <kstandarddirs.h>
@@ -85,11 +85,11 @@ K3bSystemProblemDialog::K3bSystemProblemDialog( const QValueList<K3bSystemProble
   layout4->addWidget( pixmapLabelRight );
 
 
-  if( K3bTheme* theme = k3bthememanager->currentTheme() ) {
+  if( K3bTheme* theme = k3bappcore->themeManager()->currentTheme() ) {
     pixmapLabelLeft->setPaletteBackgroundColor( theme->backgroundColor() );
-    pixmapLabelLeft->setPixmap( theme->pixmap( "diskinfo_left" ) );
+    pixmapLabelLeft->setPixmap( theme->pixmap( K3bTheme::MEDIA_LEFT ) );
     pixmapLabelRight->setPaletteBackgroundColor( theme->backgroundColor() );
-    pixmapLabelRight->setPixmap( theme->pixmap( "diskinfo_right" ) );
+    pixmapLabelRight->setPixmap( theme->pixmap( K3bTheme::MEDIA_NONE ) );
     labelTitle->setPaletteBackgroundColor( theme->backgroundColor() );
     labelTitle->setPaletteForegroundColor( theme->foregroundColor() );
   }
@@ -181,7 +181,7 @@ void K3bSystemProblemDialog::checkSystem( QWidget* parent,
 				       false ) );
   }
   else {
-    if( k3bcore->externalBinManager()->binObject( "cdrecord" )->version < K3bVersion( 2, 0 ) )
+    if( k3bcore->externalBinManager()->binObject( "cdrecord" )->version < K3bVersion( 2, 0 ) ) {
       problems.append( K3bSystemProblem( K3bSystemProblem::NON_CRITICAL,
 					 i18n("Used %1 version %2 is outdated").arg("cdrecord").arg(k3bcore->externalBinManager()->binObject( "cdrecord" )->version),
 					 i18n("Although K3b supports all cdrtools versions since "
@@ -189,11 +189,26 @@ void K3bSystemProblemDialog::checkSystem( QWidget* parent,
 					      "version 2.0."),
 					 i18n("Install a more recent version of the cdrtools."),
 					 false ) );
+    }
     
-    if( !k3bcore->externalBinManager()->binObject( "cdrecord" )->hasFeature( "suidroot" ) &&
-	K3b::simpleKernelVersion() < K3bVersion( 2, 6, 8 ) )
+#ifdef Q_OS_LINUX
+
+    //
+    // Since kernel 2.6.8 cdrecord is not able to use the SCSI subsystem when running suid root anymore
+    // So for now (until cdrecord has been properly patched) we ignore the suid root issue with kernel >= 2.6.8
+    //
+    if( K3b::simpleKernelVersion() >= K3bVersion( 2, 6, 8 ) ) {
+      if( k3bcore->externalBinManager()->binObject( "cdrecord" )->hasFeature( "suidroot" ) )
+	problems.append( K3bSystemProblem( K3bSystemProblem::CRITICAL,
+					   i18n("%1 will be run with root privileges on kernel >= 2.6.8").arg("cdrecord"),
+					   i18n("Since Linux kernel 2.6.8 %1 will not work when run suid "
+						"root for security reasons anymore.").arg("cdrecord"),
+					   i18n("Use K3bSetup to solve this problem."),
+					   true ) );
+    }
+    else if( !k3bcore->externalBinManager()->binObject( "cdrecord" )->hasFeature( "suidroot" ) && getuid() != 0 ) // not root
       problems.append( K3bSystemProblem( K3bSystemProblem::CRITICAL,
-					 i18n("%1 does not run with root privileges").arg("cdrecord"),
+					 i18n("%1 will be run without root privileges").arg("cdrecord"),
 					 i18n("It is highly recommended to configure cdrecord "
 					      "to run with root privileges. Only then cdrecord "
 					      "runs with high priority which increases the overall "
@@ -203,8 +218,9 @@ void K3bSystemProblemDialog::checkSystem( QWidget* parent,
 					      "true when using SuSE's resmgr."),
 					 i18n("Use K3bSetup to solve this problem."),
 					 true ) );
+#endif
   }
-  
+
   if( !k3bcore->externalBinManager()->foundBin( "cdrdao" ) ) {
     problems.append( K3bSystemProblem( K3bSystemProblem::CRITICAL,
 				       i18n("Unable to find %1 executable").arg("cdrdao"),
@@ -212,18 +228,20 @@ void K3bSystemProblemDialog::checkSystem( QWidget* parent,
 				       i18n("Install the cdrdao package."),
 				       false ) );
   }
-  else if( !k3bcore->externalBinManager()->binObject( "cdrdao" )->hasFeature( "suidroot" ) &&
-	   K3b::simpleKernelVersion() < K3bVersion( 2, 6, 8 ) ) {
-    problems.append( K3bSystemProblem( K3bSystemProblem::CRITICAL,
-				       i18n("%1 does not run with root privileges").arg("cdrdao"),
-				       i18n("It is highly recommended to configure cdrdao "
-					    "to run with root privileges to increase the "
-					    "overall stability of the burning process."),
-				       i18n("Use K3bSetup to solve this problem."),
-				       true ) );
+  else {
+#ifdef Q_OS_LINUX
+    if( K3b::simpleKernelVersion() < K3bVersion( 2, 6, 8 ) &&
+	!k3bcore->externalBinManager()->binObject( "cdrdao" )->hasFeature( "suidroot" ) && getuid() != 0 )
+      problems.append( K3bSystemProblem( K3bSystemProblem::CRITICAL,
+					 i18n("%1 will be run without root privileges").arg("cdrdao"),
+					 i18n("It is highly recommended to configure cdrdao "
+					      "to run with root privileges to increase the "
+					      "overall stability of the burning process."),
+					 i18n("Use K3bSetup to solve this problem."),
+					 true ) );
+#endif
   }
 
-
   if( !k3bcore->deviceManager()->dvdWriter().isEmpty() ) {
     if( !k3bcore->externalBinManager()->foundBin( "growisofs" ) ) {
       problems.append( K3bSystemProblem( K3bSystemProblem::CRITICAL,
@@ -240,7 +258,7 @@ void K3bSystemProblemDialog::checkSystem( QWidget* parent,
 					   i18n("Used %1 version %2 is outdated").arg("growisofs").arg(k3bcore->externalBinManager()->binObject( "growisofs" )->version),
 					   i18n("K3b needs at least growisofs version 5.10 to write dvds. "
 						"All older versions will not work and K3b will refuse to use them."),
-					   i18n("Install a more recent version of growisofs."),
+					   i18n("Install a more recent version of %1.").arg("growisofs"),
 					   false ) );
       }
       else if( k3bcore->externalBinManager()->binObject( "growisofs" )->version < K3bVersion( 5, 12 ) ) {
@@ -262,21 +280,46 @@ void K3bSystemProblemDialog::checkSystem( QWidget* parent,
     }
   }
 
+  if( !k3bcore->externalBinManager()->foundBin( "mkisofs" ) ) {
+
+  }
+  else if( k3bcore->externalBinManager()->binObject( "mkisofs" )->version < K3bVersion( 1, 14 ) ) {
+      problems.append( K3bSystemProblem( K3bSystemProblem::CRITICAL,
+					 i18n("Used %1 version %2 is outdated")
+					 .arg("mkisofs")
+					 .arg(k3bcore->externalBinManager()->binObject( "mkisofs" )->version),
+					 i18n("K3b needs at least mkisofs version 1.14. Older versions may introduce problems "
+					      "when creating data projects."),
+					 i18n("Install a more recent version of %1.").arg("mkisofs"),
+					 false ) );
+  }
+
   // 2. ATAPI devices
   bool atapiReader = false;
   bool atapiWriter = false;
-  for( QPtrListIterator<K3bCdDevice::CdDevice> it( k3bcore->deviceManager()->readingDevices() );
+  for( QPtrListIterator<K3bDevice::Device> it( k3bcore->deviceManager()->readingDevices() );
        it.current(); ++it ) {
-    if( it.current()->interfaceType() == K3bCdDevice::CdDevice::IDE ) {
+    if( it.current()->interfaceType() == K3bDevice::IDE ) {
       atapiReader = true;
       break;
     }
   }
-  for( QPtrListIterator<K3bCdDevice::CdDevice> it( k3bcore->deviceManager()->burningDevices() );
+  for( QPtrListIterator<K3bDevice::Device> it( k3bcore->deviceManager()->burningDevices() );
        it.current(); ++it ) {
-    if( it.current()->interfaceType() == K3bCdDevice::CdDevice::IDE ) {
+    if( it.current()->interfaceType() == K3bDevice::IDE ) {
       atapiWriter = true;
-      break;
+    }
+
+    if( it.current()->automount() ) {
+      problems.append( K3bSystemProblem( K3bSystemProblem::NON_CRITICAL,
+					 i18n("Writing device %1 - %2 is automounted.")
+					 .arg(it.current()->vendor()).arg(it.current()->description()),
+					 i18n("Automounting can cause problems with CD/DVD writing, especially "
+					      "with rewritable media. Although it might all work just fine it "
+					      "is recommended to disable automounting completely for now."),
+					 i18n("Replace the automounting entries in /etc/fstab with old-fashioned "
+					      "ones."),
+					 false ) );
     }
   }
 
@@ -325,16 +368,20 @@ void K3bSystemProblemDialog::checkSystem( QWidget* parent,
 	if( !k3bcore->externalBinManager()->binObject( "cdrdao" )->hasFeature( "hacked-atapi" ) &&
 	    !k3bcore->externalBinManager()->binObject( "cdrdao" )->hasFeature( "plain-atapi") ) {
 	  problems.append( K3bSystemProblem( K3bSystemProblem::CRITICAL,
-					     i18n("%1 %2 does not support ATAPI").arg("cdrdao").arg(k3bcore->externalBinManager()->binObject("cdrdao")->version),
+					     i18n("%1 %2 does not support ATAPI")
+					     .arg("cdrdao").arg(k3bcore->externalBinManager()->binObject("cdrdao")->version),
 					     i18n("The configured version of %1 does not "
 						  "support writing to ATAPI devices without "
 						  "SCSI emulation and there is at least one writer "
 						  "in your system not configured to use "
 						  "SCSI emulation.").arg("cdrdao"),
-					     i18n("The best and recommended solution is to enable "
-						  "ide-scsi (SCSI emulation) for all writer devices. "
-						  "This way you won't have any problems. Or you install "
-						  "(or select as the default) a more recent version of %1.").arg("cdrdao"),
+					     K3b::simpleKernelVersion() > K3bVersion( 2, 5, 0 )
+					     ? i18n("Install cdrdao >= 1.1.8 which supports writing to "
+						    "ATAPI devices directly.")
+					     : i18n("The best, and recommended, solution is to use "
+						    "ide-scsi (SCSI emulation) for all writer devices: "
+						    "this way you will not have any problems; or, you can install "
+						    "(or select as the default) a more recent version of %1.").arg("cdrdao"),
 					     false ) );
 	}
       }
@@ -342,6 +389,31 @@ void K3bSystemProblemDialog::checkSystem( QWidget* parent,
   }
 
 
+  for( QPtrListIterator<K3bDevice::Device> it( k3bcore->deviceManager()->allDevices() );
+       it.current(); ++it ) {
+    if( !QFileInfo( it.current()->blockDeviceName() ).isWritable() )
+      problems.append( K3bSystemProblem( K3bSystemProblem::CRITICAL,
+					 i18n("No write access to device %1").arg(it.current()->blockDeviceName()),
+					 i18n("K3b needs write access to all the devices to perform certain tasks. "
+					      "Without you might encounter problems with %1 - %2").arg(it.current()->vendor()).arg(it.current()->description()),
+					 i18n("Make sure you have write access to %1. In case you are not using "
+					      "devfs or udev K3bSetup is able to do this for you.").arg(it.current()->blockDeviceName()),
+					 false ) );
+
+
+    if( it.current()->interfaceType() == K3bDevice::SCSI &&
+	!it.current()->genericDevice().isEmpty() &&
+	!QFileInfo( it.current()->genericDevice() ).isWritable() )
+      problems.append( K3bSystemProblem( K3bSystemProblem::CRITICAL,
+					 i18n("No write access to generic SCSI device %1").arg(it.current()->genericDevice()),
+					 i18n("Without write access to the generic device you might "
+					      "encounter problems with Audio CD ripping from %1 - %2").arg(it.current()->vendor()).arg(it.current()->description()),
+					 i18n("Make sure you have write access to %1. In case you are not using "
+					      "devfs or udev K3bSetup is able to do this for you.").arg(it.current()->genericDevice()),
+					 false ) );
+  }
+
+
   kdDebug() << "(K3bCore) System problems:" << endl;
   for( QValueList<K3bSystemProblem>::const_iterator it = problems.begin();
        it != problems.end(); ++it ) {
@@ -370,7 +442,6 @@ void K3bSystemProblemDialog::checkSystem( QWidget* parent,
   }
 }
 
-
 void K3bSystemProblemDialog::slotK3bSetup()
 {
   KProcess p;
