@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdevicewidget.cpp,v 1.5.2.1 2004/11/23 19:39:47 trueg Exp $
+ * $Id$
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -20,7 +20,7 @@
 #include "k3bdeviceglobals.h"
 #include <k3blistview.h>
 
-#include <klineeditdlg.h>
+#include <kinputdialog.h>
 #include <kmessagebox.h>
 #include <knuminput.h>
 #include <kdialog.h>
@@ -46,7 +46,7 @@
 class K3bDeviceWidget::PrivateTempDevice
 {
 public:
-  PrivateTempDevice( K3bDevice* d ) {
+  PrivateTempDevice( K3bDevice::Device* d ) {
     device = d;
     cdrdaoDriver = d->cdrdaoDriver();
     maxReadSpeed = d->maxReadSpeed() / 175;
@@ -55,7 +55,7 @@ public:
     writer = d->burner();
   }
 
-  K3bDevice* device;
+  K3bDevice::Device* device;
   int maxReadSpeed;
   int maxWriteSpeed;
   QString cdrdaoDriver;
@@ -143,7 +143,7 @@ private:
     case t_cdrdaoDriver:
       if( l.isEmpty() )
 	for( int i = 0; i < 13; i++ )
-	  l.append(K3bDevice::cdrdao_drivers[i]);
+	  l.append(K3bDevice::Device::cdrdao_drivers[i]);
 
       setEditor( 1, COMBO, l );
       break;
@@ -166,7 +166,7 @@ private:
 
 
 
-K3bDeviceWidget::K3bDeviceWidget( K3bDeviceManager* manager, QWidget *parent, const char *name )
+K3bDeviceWidget::K3bDeviceWidget( K3bDevice::DeviceManager* manager, QWidget *parent, const char *name )
   : QWidget( parent, name ), m_deviceManager( manager )
 {
   QGridLayout* frameLayout = new QGridLayout( this );
@@ -204,7 +204,7 @@ K3bDeviceWidget::K3bDeviceWidget( K3bDeviceManager* manager, QWidget *parent, co
   m_viewDevices->setDoubleClickForEdit(false);
   m_viewDevices->setAlternateBackground( QColor() );
   m_viewDevices->setSelectionMode( QListView::NoSelection );
-  m_viewDevices->setFullWidth();
+  m_viewDevices->setFullWidth(true);
   // ------------------------------------------------
 
 
@@ -223,10 +223,9 @@ K3bDeviceWidget::K3bDeviceWidget( K3bDeviceManager* manager, QWidget *parent, co
   //  connect( m_buttonRefreshDevices, SIGNAL(clicked()), this, SLOT(slotRefreshDevices()) );
   connect( m_buttonRefreshDevices, SIGNAL(clicked()), this, SIGNAL(refreshButtonClicked()) );
   connect( m_buttonAddDevice, SIGNAL(clicked()), this, SLOT(slotNewDevice()) );
-  // ------------------------------------------------
 
-  // makes K3b crash
-  m_buttonRefreshDevices->hide();
+  connect( m_deviceManager, SIGNAL(changed()), this, SLOT(updateDeviceListViews()) );
+  // ------------------------------------------------
 }
 
 
@@ -242,7 +241,7 @@ void K3bDeviceWidget::init()
   m_tempDevices.clear();
 
   // add the reading devices
-  K3bDevice* dev = m_deviceManager->allDevices().first();
+  K3bDevice::Device* dev = m_deviceManager->allDevices().first();
   while( dev ) {
     m_tempDevices.append( new PrivateTempDevice( dev ) );
     dev = m_deviceManager->allDevices().next();
@@ -258,23 +257,25 @@ void K3bDeviceWidget::updateDeviceListViews()
 
   // create the parent view items
   // -----------------------------------------
-  m_writerParentViewItem = new QListViewItem( m_viewDevices, i18n("Writer") );
+  m_writerParentViewItem = new QListViewItem( m_viewDevices, i18n("Writer Drives") );
   m_writerParentViewItem->setPixmap( 0, SmallIcon( "cdwriter_unmount" ) );
   // spacer item
   (void)new QListViewItem( m_viewDevices );
-  m_readerParentViewItem = new QListViewItem( m_viewDevices, i18n("Reader") );
+  m_readerParentViewItem = new QListViewItem( m_viewDevices, i18n("Readonly Drives") );
   m_readerParentViewItem->setPixmap( 0, SmallIcon( "cdrom_unmount" ) );
   // -----------------------------------------
 
+  QFont fBold( m_viewDevices->font() );
+  fBold.setBold(true);
+  QFont fItalic( m_viewDevices->font() );
+  fItalic.setItalic(true);
 
   PrivateTempDevice* dev = m_tempDevices.first();
   while( dev ) {
     // create the root device item
     K3bListViewItem* devRoot = new K3bListViewItem( (dev->writer ? m_writerParentViewItem : m_readerParentViewItem),
 						    dev->device->vendor() + " " + dev->device->description() );
-    QFont f( m_viewDevices->font() );
-    f.setBold(true);
-    devRoot->setFont( 0, f );
+    devRoot->setFont( 0, fBold );
 
     // create the read-only info items
     K3bListViewItem* systemDeviceItem = new K3bListViewItem( devRoot, i18n("System device name:") );
@@ -300,7 +301,7 @@ void K3bDeviceWidget::updateDeviceListViews()
 						   dev->device->description() );
     modelItem->setForegroundColor( 1, gray );
     K3bListViewItem* versionItem = new K3bListViewItem( devRoot, modelItem,
-						   i18n("Version:"),
+						   i18n("Firmware:"),
 						   dev->device->version() );
     versionItem->setForegroundColor( 1, gray );
 
@@ -308,25 +309,35 @@ void K3bDeviceWidget::updateDeviceListViews()
     // drive type
     // --------------------------------
     K3bListViewItem* typeItem = new K3bListViewItem( devRoot, versionItem,
-						     i18n("Writes CDs:"),
+						     i18n("Writes CD-R:"),
 						     dev->device->writesCd() ? i18n("yes") : i18n("no") );
     typeItem->setForegroundColor( 1, gray );
     typeItem = new K3bListViewItem( devRoot, typeItem,
-				    i18n("Writes CD/RWs:"),
+				    i18n("Writes CD-RW:"),
 				    dev->device->writesCdrw() ? i18n("yes") : i18n("no") );
     typeItem->setForegroundColor( 1, gray );
     typeItem = new K3bListViewItem( devRoot, typeItem, 
-				    i18n("Reads DVDs:"),
+				    i18n("Reads DVD:"),
 				    dev->device->readsDvd() ? i18n("yes") : i18n("no") );
     typeItem->setForegroundColor( 1, gray );
     typeItem = new K3bListViewItem( devRoot, typeItem,
-				    i18n("Writes DVD-R(W)s:"),
+				    i18n("Writes DVD-R(W):"),
 				    dev->device->writesDvdMinus() ? i18n("yes") : i18n("no") );
     typeItem->setForegroundColor( 1, gray );
     typeItem = new K3bListViewItem( devRoot, typeItem,
-				    i18n("Writes DVD+R(W)s:"),
+				    i18n("Writes DVD-R Dual Layer:"),
+				    (dev->device->type() & K3bDevice::DEVICE_DVD_R_DL)
+				    ? i18n("yes") : i18n("no") );
+    typeItem->setForegroundColor( 1, gray );
+    typeItem = new K3bListViewItem( devRoot, typeItem,
+				    i18n("Writes DVD+R(W):"),
 				    dev->device->writesDvdPlus() ? i18n("yes") : i18n("no") );
     typeItem->setForegroundColor( 1, gray );
+    typeItem = new K3bListViewItem( devRoot, typeItem,
+				    i18n("Writes DVD+R Double Layer:"),
+				    (dev->device->type() & K3bDevice::DEVICE_DVD_PLUS_R_DL)
+				    ? i18n("yes") : i18n("no") );
+    typeItem->setForegroundColor( 1, gray );
     // --------------------------------
 
 
@@ -373,7 +384,7 @@ void K3bDeviceWidget::updateDeviceListViews()
       (new K3bListViewItem( devRoot, 
 			    typeItem, 
 			    i18n("Write modes:"), 
-			    K3bCdDevice::writingModeString(dev->device->writingModes()) ))->setForegroundColor( 1, gray );
+			    K3bDevice::writingModeString(dev->device->writingModes()) ))->setForegroundColor( 1, gray );
     }
 
     devRoot->setOpen(true);
@@ -381,6 +392,16 @@ void K3bDeviceWidget::updateDeviceListViews()
     dev = m_tempDevices.next();
   }
 
+  // create empty items
+  if( m_writerParentViewItem->childCount() == 0 ) {
+    K3bListViewItem* item = new K3bListViewItem( m_writerParentViewItem, i18n("none") );
+    item->setFont( 0, fItalic );
+  }
+  if( m_readerParentViewItem->childCount() == 0 ) {
+    K3bListViewItem* item = new K3bListViewItem( m_readerParentViewItem, i18n("none") );
+    item->setFont( 0, fItalic );
+  }
+
   m_writerParentViewItem->setOpen( true );
   m_readerParentViewItem->setOpen( true );
 }
@@ -389,10 +410,12 @@ void K3bDeviceWidget::updateDeviceListViews()
 void K3bDeviceWidget::slotNewDevice()
 {
   bool ok;
-  QString newDevicename = KLineEditDlg::getText( i18n("Please enter the device name where K3b should search\nfor a new drive (example: /dev/mebecdrom):"), "/dev/", &ok, this );
+  QString newDevicename = KInputDialog::getText( i18n("Location of New Drive"),
+						 i18n("Please enter the device name where K3b should search\nfor a new drive (example: /dev/cdrom):"),
+						 "/dev/", &ok, this );
 
   if( ok ) {
-    if( K3bDevice* dev = m_deviceManager->addDevice( newDevicename ) ) {
+    if( K3bDevice::Device* dev = m_deviceManager->addDevice( newDevicename ) ) {
       m_tempDevices.append( new PrivateTempDevice( dev ) );
 
       updateDeviceListViews();
