@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3baudiocdview.cpp,v 1.18.2.1 2004/06/23 21:21:44 trueg Exp $
+ * $Id: k3baudiocdview.cpp 409817 2005-05-05 18:44:15Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -15,21 +15,23 @@
 
 #include "k3baudiocdview.h"
 #include "k3baudiorippingdialog.h"
+#include "k3baudiocdlistview.h"
 
 #include <k3btoc.h>
 #include <k3bdiskinfo.h>
 #include <k3bdevicehandler.h>
 #include <k3blistview.h>
-#include <cddb/k3bcddbresult.h>
+#include <k3bcddbresult.h>
 #include <k3bmsf.h>
-#include <cddb/k3bcddb.h>
-#include <cddb/k3bcddbquery.h>
+#include <k3bcddb.h>
+#include <k3bcddbquery.h>
 #include <k3btoolbox.h>
 #include <kcutlabel.h>
 #include <k3bstdguiitems.h>
-#include <k3bcore.h>
+#include <k3bapplication.h>
 #include <cdinfo/k3bdiskinfodetector.h>
 #include <k3bthememanager.h>
+#include <k3baudiocdtrackdrag.h>
 
 #include <klocale.h>
 #include <kdebug.h>
@@ -49,8 +51,9 @@
 #include <qframe.h>
 #include <qspinbox.h>
 #include <qfont.h>
+#include <qdragobject.h>
 
-
+// FIXME: use a K3bListViewItem which can be checked
 class K3bAudioCdView::AudioTrackViewItem : public QCheckListItem
 {
 public:
@@ -64,13 +67,19 @@ public:
 		      QCheckListItem::CheckBox ) {
     setText( 1, QString::number(_trackNumber).rightJustify( 2, ' ' ) );
     setText( 3, i18n("Track %1").arg(_trackNumber) );
-    setText( 4, length.toString() );
-    setText( 5, KIO::convertSize( length.audioBytes() ) );
+    setText( 4, " " + length.toString() + " " );
+    setText( 5, " " + KIO::convertSize( length.audioBytes() ) + " " );
 
     trackNumber = _trackNumber;
     setOn(true);
   }
 
+  void setup() {
+    QCheckListItem::setup();
+    
+    setHeight( height() + 4 );
+  }
+
   int trackNumber;
 
   void updateCddbData( const K3bCddbResultEntry& entry ) {
@@ -99,36 +108,14 @@ K3bAudioCdView::K3bAudioCdView( QWidget* parent, const char *name )
 
   // the track view
   // ----------------------------------------------------------------------------------
-  m_trackView = new K3bListView( mainWidget() );
-  m_trackView->setFullWidth(true);
-  m_trackView->setSorting(-1);
-  m_trackView->setAllColumnsShowFocus( true );
-  m_trackView->setSelectionMode( QListView::Single );
-  m_trackView->setDragEnabled( true );
-  m_trackView->addColumn( "" );
-  m_trackView->addColumn( "" );
-  m_trackView->addColumn( i18n("Artist") );
-  m_trackView->addColumn( i18n("Title") );
-  m_trackView->addColumn( i18n("Length") );
-  m_trackView->addColumn( i18n("Size") );
-
-  m_trackView->header()->setClickEnabled(false);
-  m_trackView->setColumnWidthMode( 0, QListView::Manual );
-  m_trackView->setColumnWidth( 0, 20 );
-  m_trackView->header()->setResizeEnabled( false,0 );
-
-  m_trackView->setItemsRenameable(true);
-  m_trackView->setRenameable(0, false);
-  m_trackView->setRenameable(1, false);
-  m_trackView->setRenameable(2, true);
-  m_trackView->setRenameable(3, true);
+  m_trackView = new K3bAudioCdListView( this, mainWidget() );
 
   connect( m_trackView, SIGNAL(itemRenamed(QListViewItem*, const QString&, int)),
 	   this, SLOT(slotItemRenamed(QListViewItem*, const QString&, int)) );
   connect( m_trackView, SIGNAL(contextMenu(KListView*, QListViewItem*, const QPoint&)),
 	   this, SLOT(slotContextMenu(KListView*, QListViewItem*, const QPoint&)) );
-  connect( m_trackView, SIGNAL(selectionChanged(QListViewItem*)), 
-	   this, SLOT(slotTrackSelectionChanged(QListViewItem*)) );
+//   connect( m_trackView, SIGNAL(selectionChanged(QListViewItem*)), 
+// 	   this, SLOT(slotTrackSelectionChanged(QListViewItem*)) );
 
   mainGrid->addLayout( toolBoxLayout, 0, 0 );
   mainGrid->addWidget( m_trackView, 1, 0 );
@@ -137,17 +124,17 @@ K3bAudioCdView::K3bAudioCdView( QWidget* parent, const char *name )
   m_cddb = new K3bCddb( this );
 
   connect( m_cddb, SIGNAL(infoMessage(const QString&)),
-	   k3bcore, SLOT(requestBusyInfo(const QString&)) );
+	   k3bappcore, SLOT(requestBusyInfo(const QString&)) );
   connect( m_cddb, SIGNAL(queryFinished(int)),
-	   k3bcore, SLOT(requestBusyFinish()) );
+	   k3bappcore, SLOT(requestBusyFinish()) );
   connect( m_cddb, SIGNAL(queryFinished(int)),
 	   this, SLOT(slotCddbQueryFinished(int)) );
 
   initActions();
-  slotTrackSelectionChanged(0);
+  //  slotTrackSelectionChanged(0);
 
-  setLeftPixmap( "diskinfo_left" );
-  setRightPixmap( "diskinfo_audio" );
+  setLeftPixmap( K3bTheme::MEDIA_LEFT );
+  setRightPixmap( K3bTheme::MEDIA_AUDIO );
 }
 
 
@@ -156,7 +143,7 @@ K3bAudioCdView::~K3bAudioCdView()
 }
 
 
-void K3bAudioCdView::setDisk( K3bCdDevice::DiskInfoDetector* did )
+void K3bAudioCdView::setDisk( K3bDevice::DiskInfoDetector* did )
 {
   m_toc = did->toc();
   m_device = did->device();
@@ -205,9 +192,9 @@ void K3bAudioCdView::reload()
   m_cddbInfo.cdExtInfo = m_cdText.message();
 
   for( unsigned int i = 0; i < m_cdText.count(); ++i ) {
-    m_cddbInfo.titles[i] = m_cdText.trackCdText(i).title();
-    m_cddbInfo.artists[i] = m_cdText.trackCdText(i).performer();
-    m_cddbInfo.extInfos[i] = m_cdText.trackCdText(i).message();
+    m_cddbInfo.titles[i] = m_cdText[i].title();
+    m_cddbInfo.artists[i] = m_cdText[i].performer();
+    m_cddbInfo.extInfos[i] = m_cdText[i].message();
   }
 
   updateDisplay();
@@ -259,7 +246,7 @@ void K3bAudioCdView::initActions()
   KAction* actionQueryCddb = new KAction( i18n("Query cddb"), "reload", 0, this,
 					  SLOT(queryCddb()), actionCollection(), "query_cddb" );
 
-  KAction* actionSaveCddbLocally = new KAction( i18n("Save Cddb entry locally"), "filesave", 0, this,
+  KAction* actionSaveCddbLocally = new KAction( i18n("Save Cddb Entry Locally"), "filesave", 0, this,
 						SLOT(slotSaveCddbLocally()), actionCollection(), "save_cddb_local" );
 
   // TODO: set the actions tooltips and whatsthis infos
@@ -278,11 +265,12 @@ void K3bAudioCdView::initActions()
   m_popupMenu->insert( actionStartRip );
 
   // setup the toolbox
+  m_toolBox->addButton( actionStartRip );
+  m_toolBox->addSpacing();
   m_toolBox->addButton( actionQueryCddb );
   m_toolBox->addButton( actionSaveCddbLocally );
   m_toolBox->addButton( actionEditTrackCddbInfo );
   m_toolBox->addButton( actionEditAlbumCddbInfo );
-  m_toolBox->addButton( actionStartRip );
 }
 
 
@@ -338,8 +326,10 @@ void K3bAudioCdView::startRip()
 
 void K3bAudioCdView::slotEditTrackCddb()
 {
-  if( QListViewItem* item = m_trackView->selectedItem() ) {
-    AudioTrackViewItem* a = (AudioTrackViewItem*)item;
+  QPtrList<QListViewItem> items( m_trackView->selectedItems() );
+  if( !items.isEmpty() ) {
+    AudioTrackViewItem* a = static_cast<AudioTrackViewItem*>(items.first());
+
     KDialogBase d( this, "trackCddbDialog", true, i18n("Cddb Track %1").arg(a->trackNumber),
 		   KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true);
     QWidget* w = new QWidget( &d );
@@ -454,7 +444,7 @@ void K3bAudioCdView::queryCddb()
 
 void K3bAudioCdView::slotCddbQueryFinished( int error )
 {
-  k3bcore->requestBusyFinish();
+  k3bappcore->requestBusyFinish();
 
   if( error == K3bCddbQuery::SUCCESS ) {
     m_cddbInfo = m_cddb->result();
@@ -558,14 +548,18 @@ void K3bAudioCdView::slotDeselectAll()
 
 void K3bAudioCdView::slotSelect()
 {
-  if( QListViewItem* sel = m_trackView->selectedItem() )
-    ((AudioTrackViewItem*)sel)->setOn(true);
+  QPtrList<QListViewItem> items( m_trackView->selectedItems() );
+  for( QPtrListIterator<QListViewItem> it( items );
+       it.current(); ++it )
+    static_cast<AudioTrackViewItem*>(it.current())->setOn(true);
 }
 
 void K3bAudioCdView::slotDeselect()
 {
-  if( QListViewItem* sel = m_trackView->selectedItem() )
-    ((AudioTrackViewItem*)sel)->setOn(false);
+  QPtrList<QListViewItem> items( m_trackView->selectedItems() );
+  for( QPtrListIterator<QListViewItem> it( items );
+       it.current(); ++it )
+    static_cast<AudioTrackViewItem*>(it.current())->setOn(false);
 }
 
 void K3bAudioCdView::updateDisplay()
@@ -598,4 +592,23 @@ void K3bAudioCdView::enableInteraction( bool b )
 }
 
 
+QDragObject* K3bAudioCdView::dragObject()
+{
+  QPtrList<QListViewItem> items = m_trackView->selectedItems();
+  QValueList<int> tracks;
+  for( QPtrListIterator<QListViewItem> it( items );
+       it.current(); ++it )
+    tracks.append( static_cast<AudioTrackViewItem*>(it.current())->trackNumber );
+
+  if( !items.isEmpty() ) {
+    return new K3bAudioCdTrackDrag( m_toc, 
+				    tracks, 
+				    m_cddbInfo,
+				    m_device,
+				    this );
+  }
+  else
+    return 0;
+}
+
 #include "k3baudiocdview.moc"
