@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3baudiorippingdialog.cpp,v 1.26.2.1 2004/06/14 16:13:59 trueg Exp $
- * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
+ * $Id: k3baudiorippingdialog.cpp 401319 2005-03-28 16:26:58Z trueg $
+ * Copyright (C) 2003-2005 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2005 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,11 +18,9 @@
 #include "k3baudioripthread.h"
 #include "k3bpatternparser.h"
 #include "k3bcddbpatternwidget.h"
-#include "base_k3baudiorippingoptionwidget.h"
+#include "k3baudioconvertingoptionwidget.h"
 
 #include <k3bjobprogressdialog.h>
-#include "songdb/k3bsong.h"
-#include "songdb/k3bsongmanager.h"
 #include <k3bcore.h>
 #include <k3bglobals.h>
 #include <k3btrack.h>
@@ -75,19 +73,22 @@ public:
   Private() {
   }
 
-  QIntDict<K3bAudioEncoderFactory> factoryMap;
   QValueVector<QString> filenames;
-  QMap<int, QString> extensionMap;
   QString playlistFilename;
 };
 
 
-K3bAudioRippingDialog::K3bAudioRippingDialog(const K3bCdDevice::Toc& toc, 
-					     K3bCdDevice::CdDevice* device,
+K3bAudioRippingDialog::K3bAudioRippingDialog(const K3bDevice::Toc& toc, 
+					     K3bDevice::Device* device,
 					     const K3bCddbResultEntry& entry, 
 					     const QValueList<int>& tracks,
 					     QWidget *parent, const char *name )
-  : K3bInteractionDialog( parent, name ),
+  : K3bInteractionDialog( parent, name,
+			  QString::null,
+			  QString::null,
+			  START_BUTTON|CANCEL_BUTTON,
+			  START_BUTTON,
+			  "Audio Ripping" ), // config group
     m_toc( toc ), 
     m_device( device ),
     m_cddbEntry( entry ), 
@@ -98,8 +99,6 @@ K3bAudioRippingDialog::K3bAudioRippingDialog(const K3bCdDevice::Toc& toc,
   setupGui();
   setupContextHelp();
 
-  init();
-
   K3b::Msf length;
   for( QValueList<int>::const_iterator it = m_trackNumbers.begin();
        it != m_trackNumbers.end(); ++it ) {
@@ -135,12 +134,9 @@ void K3bAudioRippingDialog::setupGui()
 
   QTabWidget* mainTab = new QTabWidget( frame );
 
-  m_optionWidget = new base_K3bAudioRippingOptionWidget( mainTab );
-  m_optionWidget->m_editBaseDir->setMode( KFile::Directory );
+  m_optionWidget = new K3bAudioConvertingOptionWidget( mainTab );
   mainTab->addTab( m_optionWidget, i18n("Options") );
 
-  m_optionWidget->m_buttonConfigurePlugin->setIconSet( SmallIconSet( "gear" ) );
-
 
   // setup filename pattern page
   // -------------------------------------------------------------------------------------------
@@ -148,8 +144,6 @@ void K3bAudioRippingDialog::setupGui()
   mainTab->addTab( m_patternWidget, i18n("File Naming") );
   connect( m_patternWidget, SIGNAL(changed()), this, SLOT(refresh()) );
 
-  connect( m_optionWidget->m_checkUsePattern, SIGNAL(toggled(bool)), m_patternWidget, SLOT(setEnabled(bool)) );
-
 
   // setup advanced page
   // -------------------------------------------------------------------------------------------
@@ -182,16 +176,8 @@ void K3bAudioRippingDialog::setupGui()
 
   setStartButtonText( i18n( "Start Ripping" ), i18n( "Starts copying the selected tracks") );
   
-  connect( m_optionWidget->m_checkUsePattern, SIGNAL(toggled(bool)), this, SLOT(refresh()) );
-  connect( m_optionWidget->m_checkCreatePlaylist, SIGNAL(toggled(bool)), this, SLOT(refresh()) );
-  connect( m_optionWidget->m_checkSingleFile, SIGNAL(toggled(bool)), this, SLOT(refresh()) );
   connect( m_checkUseIndex0, SIGNAL(toggled(bool)), this, SLOT(refresh()) );
-  connect( m_optionWidget->m_comboFileType, SIGNAL(activated(int)), this, SLOT(refresh()) );
-  connect( m_optionWidget->m_editBaseDir, SIGNAL(textChanged(const QString&)), this, SLOT(refresh()) );
-  connect( m_optionWidget->m_buttonConfigurePlugin, SIGNAL(clicked()), this, SLOT(slotConfigurePlugin()) );
-  connect( m_optionWidget->m_comboFileType, SIGNAL(activated(int)), this, SLOT(slotToggleAll()) );
-
-  connect( m_patternWidget->m_specialStringsLabel, SIGNAL(leftClickedURL()), this, SLOT(slotSeeSpecialStrings()) );
+  connect( m_optionWidget, SIGNAL(changed()), this, SLOT(refresh()) );
 }
 
 
@@ -220,29 +206,7 @@ void K3bAudioRippingDialog::setupContextHelp()
 
 void K3bAudioRippingDialog::init()
 {
-  d->factoryMap.clear();
-  d->extensionMap.clear();
-  m_optionWidget->m_comboFileType->clear();
-  m_optionWidget->m_comboFileType->insertItem( i18n("Wave") );
-
-  // check the available encoding plugins
-  QPtrList<K3bPluginFactory> fl = k3bpluginmanager->factories( "AudioEncoder" );
-  for( QPtrListIterator<K3bPluginFactory> it( fl ); it.current(); ++it ) {
-    K3bAudioEncoderFactory* f = (K3bAudioEncoderFactory*)it.current();
-    QStringList exL = f->extensions();
-
-    for( QStringList::const_iterator exIt = exL.begin();
-	 exIt != exL.end(); ++exIt ) {
-      d->extensionMap.insert( m_optionWidget->m_comboFileType->count(), *exIt );
-      d->factoryMap.insert( m_optionWidget->m_comboFileType->count(), f );
-      m_optionWidget->m_comboFileType->insertItem( f->fileTypeComment(*exIt) );
-    }
-  }
-
-  slotLoadUserDefaults();
   refresh();
-
-  m_patternWidget->setEnabled( m_optionWidget->m_checkUsePattern->isChecked() );
 }
 
 
@@ -275,14 +239,14 @@ void K3bAudioRippingDialog::slotStartClicked()
       filesToOverwrite.append( d->filenames[i] );
   }
 
-  if( QFile::exists( d->playlistFilename ) )
+  if( m_optionWidget->createPlaylist() && QFile::exists( d->playlistFilename ) )
     filesToOverwrite.append( d->playlistFilename );
 
   if( !filesToOverwrite.isEmpty() )
     if( KMessageBox::questionYesNoList( this, 
 					i18n("Do you want to overwrite these files?"),
 					filesToOverwrite,
-					i18n("Files exist") ) == KMessageBox::No )
+					i18n("Files Exist") ) == KMessageBox::No )
       return;
 
 
@@ -291,12 +255,12 @@ void K3bAudioRippingDialog::slotStartClicked()
   unsigned int i = 0;
   for( QValueList<int>::const_iterator trackIt = m_trackNumbers.begin();
        trackIt != m_trackNumbers.end(); ++trackIt ) {
-    tracksToRip.append( qMakePair( *trackIt, d->filenames[(m_optionWidget->m_checkSingleFile->isChecked() ? 0 : i)] ) );
+    tracksToRip.append( qMakePair( *trackIt, d->filenames[(m_optionWidget->createSingleFile() ? 0 : i)] ) );
     ++i;
   }
 
 
-  K3bAudioEncoderFactory* factory = d->factoryMap[m_optionWidget->m_comboFileType->currentItem()];  // 0 for wave
+  K3bAudioEncoder* encoder = m_optionWidget->encoder();
 
   K3bAudioRipThread* thread = new K3bAudioRipThread();
   thread->setDevice( m_device );
@@ -305,21 +269,24 @@ void K3bAudioRippingDialog::slotStartClicked()
   thread->setParanoiaMode( m_comboParanoiaMode->currentText().toInt() );
   thread->setMaxRetries( m_spinRetries->value() );
   thread->setNeverSkip( m_checkNeverSkip->isChecked() );
-  thread->setSingleFile( m_optionWidget->m_checkSingleFile->isChecked() );
-  thread->setEncoderFactory( factory );
-  thread->setWritePlaylist( m_optionWidget->m_checkCreatePlaylist->isChecked() );
+  thread->setSingleFile( m_optionWidget->createSingleFile() );
+  thread->setWriteCueFile( m_optionWidget->createCueFile() );
+  thread->setEncoder( encoder );
+  thread->setWritePlaylist( m_optionWidget->createPlaylist() );
   thread->setPlaylistFilename( d->playlistFilename );
-  thread->setUseRelativePathInPlaylist( m_optionWidget->m_checkPlaylistRelative->isChecked() );
+  thread->setUseRelativePathInPlaylist( m_optionWidget->playlistRelativePath() );
   thread->setUseIndex0( m_checkUseIndex0->isChecked() );
-  if( factory )
-    thread->setFileType( d->extensionMap[m_optionWidget->m_comboFileType->currentItem()] );
-  K3bThreadJob job( thread, this );
+  if( encoder )
+    thread->setFileType( m_optionWidget->extension() );
 
-  K3bJobProgressDialog ripDialog( kapp->mainWidget(), "Ripping" );
+  K3bJobProgressDialog ripDialog( parentWidget(), "Ripping" );
+
+  K3bThreadJob job( thread, &ripDialog, this );
 
   hide();
   ripDialog.startJob(&job);
 
+  kdDebug() << "(K3bAudioRippingDialog) deleting ripthread." << endl;
   delete thread;
 
   close();
@@ -328,15 +295,14 @@ void K3bAudioRippingDialog::slotStartClicked()
 
 void K3bAudioRippingDialog::refresh()
 {
-  KConfig* c = k3bcore->config();
-  c->setGroup( "Audio Ripping" );
-
   m_viewTracks->clear();
   d->filenames.clear();
 
-  QString baseDir = K3b::prepareDir( m_optionWidget->m_editBaseDir->url() );
+  QString baseDir = K3b::prepareDir( m_optionWidget->baseDir() );
 
-  if( m_optionWidget->m_checkSingleFile->isChecked() ) {
+  KIO::filesize_t overallSize = 0;
+
+  if( m_optionWidget->createSingleFile() ) {
     long length = 0;
     for( QValueList<int>::const_iterator it = m_trackNumbers.begin();
 	 it != m_trackNumbers.end(); ++it ) {
@@ -348,34 +314,45 @@ void K3bAudioRippingDialog::refresh()
     QString filename;
     QString extension;
     long long fileSize = 0;
-    if( m_optionWidget->m_comboFileType->currentItem() == 0 ) {
+    if( m_optionWidget->encoder() == 0 ) {
       extension = "wav";
       fileSize = length * 2352 + 44;
     }
     else {
-      extension = d->extensionMap[m_optionWidget->m_comboFileType->currentItem()];
-      fileSize = d->factoryMap[m_optionWidget->m_comboFileType->currentItem()]->fileSize( extension, length );
+      extension = m_optionWidget->extension();
+      fileSize = m_optionWidget->encoder()->fileSize( extension, length );
     }
 
-    if( m_optionWidget->m_checkUsePattern->isChecked() && (int)m_cddbEntry.titles.count() >= 1 ) {
+    if( fileSize > 0 )
+      overallSize = fileSize;
+
+    if( (int)m_cddbEntry.titles.count() >= 1 ) {
       filename = K3bPatternParser::parsePattern( m_cddbEntry, 1,
 						 m_patternWidget->filenamePattern(),
 						 m_patternWidget->replaceBlanks(),
-						 m_patternWidget->blankReplaceString() ) + "." + extension;
+						 m_patternWidget->blankReplaceString() );
     }
     else {
-      filename = i18n("Album") + "." + extension;
+      filename = i18n("Album");
     }
 
 
     (void)new KListViewItem( m_viewTracks,
 			     m_viewTracks->lastItem(),
-			     filename,
+			     filename + "." + extension,
 			     K3b::Msf(length).toString(),
 			     fileSize < 0 ? i18n("unknown") : KIO::convertSize( fileSize ),
 			     i18n("Audio") );
 
-    d->filenames.append( K3b::fixupPath( baseDir + "/" + filename ) );
+    d->filenames.append( K3b::fixupPath( baseDir + "/" + filename + "." + extension ) );
+
+    if( m_optionWidget->createCueFile() )
+      (void)new KListViewItem( m_viewTracks,
+			       m_viewTracks->lastItem(),
+			       filename + ".cue",
+			       "-",
+			       "-",
+			       i18n("Cue-file") );
   }
   else {
     for( QValueList<int>::const_iterator it = m_trackNumbers.begin();
@@ -387,15 +364,18 @@ void K3bAudioRippingDialog::refresh()
       K3b::Msf trackLength = ( m_checkUseIndex0->isChecked() 
 			       ? m_toc[index].realAudioLength()
 			       : m_toc[index].length() );
-      if( m_optionWidget->m_comboFileType->currentItem() == 0 ) {
+      if( m_optionWidget->encoder() == 0 ) {
 	extension = "wav";
 	fileSize = trackLength.audioBytes() + 44;
       }
       else {
-	extension = d->extensionMap[m_optionWidget->m_comboFileType->currentItem()];
-	fileSize = d->factoryMap[m_optionWidget->m_comboFileType->currentItem()]->fileSize( extension, trackLength );
+	extension = m_optionWidget->extension();
+	fileSize = m_optionWidget->encoder()->fileSize( extension, trackLength );
       }
 
+      if( fileSize > 0 )
+	overallSize += fileSize;
+
       if( m_toc[index].type() == K3bTrack::DATA ) {
 	extension = ".iso";
 	continue;  // TODO: find out how to rip the iso data
@@ -404,7 +384,7 @@ void K3bAudioRippingDialog::refresh()
 
       QString filename;
 
-      if( m_optionWidget->m_checkUsePattern->isChecked() && (int)m_cddbEntry.titles.count() >= *it ) {
+      if( (int)m_cddbEntry.titles.count() >= *it ) {
 	filename = K3bPatternParser::parsePattern( m_cddbEntry, *it,
 						   m_patternWidget->filenamePattern(),
 						   m_patternWidget->replaceBlanks(),
@@ -426,11 +406,11 @@ void K3bAudioRippingDialog::refresh()
   }
 
   // create playlist item
-  if( m_optionWidget->m_checkCreatePlaylist->isChecked() ) {
+  if( m_optionWidget->createPlaylist() ) {
     QString filename = K3bPatternParser::parsePattern( m_cddbEntry, 1,
 						       m_patternWidget->playlistPattern(),
 						       m_patternWidget->replaceBlanks(),
-						       m_patternWidget->blankReplaceString() );
+						       m_patternWidget->blankReplaceString() ) + ".m3u";
 
     (void)new KListViewItem( m_viewTracks,
 			     m_viewTracks->lastItem(),
@@ -441,129 +421,56 @@ void K3bAudioRippingDialog::refresh()
     
     d->playlistFilename = K3b::fixupPath( baseDir + "/" + filename );
   }
+
+  if( overallSize > 0 )
+    m_optionWidget->setNeededSize( overallSize );
+  else
+    m_optionWidget->setNeededSize( 0 );
 }
 
 
 void K3bAudioRippingDialog::setStaticDir( const QString& path )
 {
-  m_optionWidget->m_editBaseDir->setURL( path );
+  m_optionWidget->setBaseDir( path );
 }
 
 
-void K3bAudioRippingDialog::slotLoadK3bDefaults()
+void K3bAudioRippingDialog::loadK3bDefaults()
 {
-  // set reasonable defaults
-  m_optionWidget->m_editBaseDir->setURL( QDir::homeDirPath() );
-  m_optionWidget->m_checkUsePattern->setChecked( true );
-
-  m_comboParanoiaMode->setCurrentItem( 3 );
+  m_comboParanoiaMode->setCurrentItem( 0 );
   m_spinRetries->setValue(20);
   m_checkNeverSkip->setChecked( false );
   m_checkUseIndex0->setChecked( false );
   
-  m_optionWidget->m_checkSingleFile->setChecked( false );
-
-  m_optionWidget->m_comboFileType->setCurrentItem(0); // Wave
-
+  m_optionWidget->loadDefaults();
   m_patternWidget->loadDefaults();
 
-  m_optionWidget->m_checkCreatePlaylist->setChecked(false);
-  m_optionWidget->m_checkPlaylistRelative->setChecked(false);
-
-  slotToggleAll();
+  refresh();
 }
 
-void K3bAudioRippingDialog::slotLoadUserDefaults()
+void K3bAudioRippingDialog::loadUserDefaults( KConfigBase* c )
 {
-  KConfig* c = k3bcore->config();
-  c->setGroup( "Audio Ripping" );
-
-  m_optionWidget->m_editBaseDir->setURL( c->readPathEntry( "last ripping directory", QDir::homeDirPath() ) );
-  m_optionWidget->m_checkUsePattern->setChecked( c->readBoolEntry( "use_pattern", true ) );
-
-  m_comboParanoiaMode->setCurrentItem( c->readNumEntry( "paranoia_mode", 3 ) );
+  m_comboParanoiaMode->setCurrentItem( c->readNumEntry( "paranoia_mode", 0 ) );
   m_spinRetries->setValue( c->readNumEntry( "read_retries", 20 ) );
   m_checkNeverSkip->setChecked( c->readBoolEntry( "never_skip", false ) );
   m_checkUseIndex0->setChecked( c->readBoolEntry( "use_index0", false ) );
 
-  m_optionWidget->m_checkSingleFile->setChecked( c->readBoolEntry( "single_file", false ) );
-
-  m_optionWidget->m_checkCreatePlaylist->setChecked( c->readBoolEntry( "create_playlist", false ) );
-  m_optionWidget->m_checkPlaylistRelative->setChecked( c->readBoolEntry( "relative_path_in_playlist", false ) );
-
-  QString filetype = c->readEntry( "filetype", "wav" );
-  if( filetype == "wav" )
-    m_optionWidget->m_comboFileType->setCurrentItem(0);
-  else {
-    for( QMap<int, QString>::iterator it = d->extensionMap.begin();
-	 it != d->extensionMap.end(); ++it ) {
-      if( it.data() == filetype ) {
-	m_optionWidget->m_comboFileType->setCurrentItem( it.key() );
-	break;
-      }
-    }
-  }
+  m_optionWidget->loadConfig( c );
   m_patternWidget->loadConfig( c );
 
-  slotToggleAll();
+  refresh();
 }
 
-void K3bAudioRippingDialog::slotSaveUserDefaults()
+void K3bAudioRippingDialog::saveUserDefaults( KConfigBase* c )
 {
-  KConfig* c = k3bcore->config();
-  c->setGroup( "Audio Ripping" );
-
-  c->writePathEntry( "last ripping directory", m_optionWidget->m_editBaseDir->url() );
-  c->writeEntry( "use_pattern", m_optionWidget->m_checkUsePattern->isChecked() );
-
   c->writeEntry( "paranoia_mode", m_comboParanoiaMode->currentText().toInt() );
   c->writeEntry( "read_retries", m_spinRetries->value() );
   c->writeEntry( "never_skip", m_checkNeverSkip->isChecked() );
   c->writeEntry( "use_index0", m_checkUseIndex0->isChecked() );
 
-  c->writeEntry( "single_file", m_optionWidget->m_checkSingleFile->isChecked() );
-
-  c->writeEntry( "create_playlist", m_optionWidget->m_checkCreatePlaylist->isChecked() );
-  c->writeEntry( "relative_path_in_playlist", m_optionWidget->m_checkPlaylistRelative->isChecked() );
-
-  if( d->extensionMap.contains(m_optionWidget->m_comboFileType->currentItem()) )
-    c->writeEntry( "filetype", d->extensionMap[m_optionWidget->m_comboFileType->currentItem()] );
-  else
-    c->writeEntry( "filetype", "wav" );
-
+  m_optionWidget->saveConfig( c );
   m_patternWidget->saveConfig( c );
 }
 
 
-void K3bAudioRippingDialog::slotConfigurePlugin()
-{
-  K3bAudioEncoderFactory* factory = d->factoryMap[m_optionWidget->m_comboFileType->currentItem()];  // 0 for wave
-  if( factory )
-    k3bpluginmanager->execPluginDialog( factory, this );
-}
-
-
-void K3bAudioRippingDialog::slotToggleAll()
-{
-  m_optionWidget->m_buttonConfigurePlugin->setEnabled( d->factoryMap[m_optionWidget->m_comboFileType->currentItem()] != 0 );  // 0 for wave
-}
-
-
-void K3bAudioRippingDialog::slotSeeSpecialStrings()
-{
-  QWhatsThis::display( i18n( "<p><b>Pattern special strings:</b>"
-			     "<ul>\n"
-			     "<li>%a - artist of the track\n"
-			     "<li>%t - title of the track\n"
-			     "<li>%n - track number\n"
-			     "<li>%y - year of the CD\n"
-			     "<li>%e - extended information about the track\n"
-			     "<li>%g - genre of the CD\n"
-			     "<li>%r - album artist (differs from %a only on soundtracks or compilations)\n"
-			     "<li>%m - album title\n"
-			     "<li>%x - extended information about the CD\n"
-			     "<li>%d - current date\n"
-			     "</ul>" ) );
-}
-
 #include "k3baudiorippingdialog.moc"
