@@ -1,6 +1,6 @@
 /*
 *
-* $Id: k3bvideocdview.cpp,v 1.11 2004/01/21 10:20:20 trueg Exp $
+* $Id: k3bvideocdview.cpp 358238 2004-10-27 16:16:40Z binner $
 * Copyright (C) 2003 Christian Kvasny <chris@k3b.org>
 *
 * This file is part of the K3b project.
@@ -158,8 +158,8 @@ K3bVideoCdView::K3bVideoCdView( QWidget* parent, const char *name )
     m_trackView->setAllColumnsShowFocus( true );
     m_trackView->setSelectionMode( QListView::Single );
     m_trackView->setDragEnabled( true );
-    m_trackView->addColumn( i18n( "Item name" ) );
-    m_trackView->addColumn( i18n( "Extracted name" ) );
+    m_trackView->addColumn( i18n( "Item Name" ) );
+    m_trackView->addColumn( i18n( "Extracted Name" ) );
     m_trackView->addColumn( i18n( "Length" ) );
     m_trackView->addColumn( i18n( "Size" ) );
 
@@ -198,7 +198,7 @@ K3bVideoCdView::~K3bVideoCdView()
 }
 
 
-void K3bVideoCdView::setDisk( K3bCdDevice::DiskInfoDetector* did )
+void K3bVideoCdView::setDisk( K3bDevice::DiskInfoDetector* did )
 {
   m_toc = did->toc();
     m_device = did->device();
